API docs for “spamfighter.txjsonrpc.web.test.test_jsonrpc”

# Module s.t.w.t.test_jsonrpc

Part of spamfighter.txjsonrpc.web.test View Source

Test JSON-RPC support.

Class | TestRuntimeError | Undocumented
Class | TestValueError | Undocumented
Class | Test | No class docstring; 3/10 methods documented
Class | TestAuthHeader | This is used to get the header info so that we can test
Class | JSONRPCTestCase | Undocumented
Class | JSONRPCTestCase2 | Test with proxy that doesn't add a slash.
Class | JSONRPCTestAuthenticated | Test with authenticated proxy. We run this with the same inout/ouput as
Class | JSONRPCTestIntrospection | Undocumented
Class | JSONRPCClientErrorHandling | Undocumented